@@ -103,7 +103,7 @@ namespace {
         }}
       }}
       listf.close();
-      return EXIT_SUCCESS;
+      return RET_SUCCESS;
     }
 
   private:
@@ -156,20 +156,27 @@ namespace {
     Query() : ModulePass(ID) {}
 
     bool runOnModule(Module &M){
-      Instruction *I = dyn_cast_or_null<Instruction>(walkExact(Inst1, Inst1ID, M, NULL, true));
+      Instruction *I = dyn_cast_or_null<Instruction>(walkExact(Inst1, Inst1ID, M, NULL, false));
       if (I == NULL) {
         errs() << "Query failed. Cannot find " << Inst1 << "\n";
-        return EXIT_FAILURE;
+        return RET_ERROR;
       }
       DILocation *Loc = I->getDebugLoc();
       if (Loc == NULL) {
         errs() << "Query failed. " << Inst1 << " has no source line info\n";
-        return EXIT_FAILURE; 
+        return RET_ERROR; 
       }
       if (Loc->isImplicitCode())
         errs() << "Query uncertain. " << Inst1 << " is implicit code\n";
-      errs() << Loc->getDirectory() << '/' << Loc->getFilename() << ':' << Loc->getLine() << ':' << Loc->getColumn() << "\n";
-      return EXIT_SUCCESS;
+      errs() << Loc->getDirectory() << '/' << Loc->getFilename() 
+             << ':' << Loc->getLine() << ':' << Loc->getColumn();
+      if (DebugLoc InlinedAtDL = Loc->getInlinedAt()) {
+        errs() << " @[ ";
+        InlinedAtDL.print(errs());
+        errs() << " ]";
+      }
+      errs() << "\n";
+      return RET_SUCCESS;
     }
 
     // We don't modify the program, so we preserve all analyses
@@ -187,7 +194,7 @@ namespace {
       Instruction *I = dyn_cast_or_null<Instruction>(walkExact(Inst1, Inst1ID, M, NULL, true));
       if (I == NULL) {
         errs() << "cut failed. Cannot find/use " << Inst1 << "\n";
-        return EXIT_FAILURE; }
+        return RET_ERROR; }
 
       insertNOP(I);
       // decouple the dependence from later instructions
@@ -201,7 +208,7 @@ namespace {
       // TODO: have a function as a recycle bin to store deleted inst
       I->eraseFromParent();
       errs() << "cut " << Inst1ID << "\n";
-      return EXIT_SUCCESS;}
+      return RET_SUCCESS;}
   };
 }
 
@@ -219,9 +226,11 @@ namespace {
         if (DI == NULL) errs()<<Inst1 << " ";
         if (SI == NULL) errs()<<Inst2 << " ";
         errs() << "\n";
-        return EXIT_FAILURE; }
+        return RET_ERROR; }
 
       temp = SI->clone();
+      // TODO: figure why the new API droplocation() has to consider callInst 
+      temp->setDebugLoc(DebugLoc()); // remove debug information if any 
       Inst2ID = getUID(SI).str();
 
       temp->insertBefore(&*DI); // insert temp before DI
@@ -235,7 +244,7 @@ namespace {
         useResult(temp); // wire outgoing results of temp into CFG
 
       errs()<<"inserted " << Inst1ID << "," << Inst2ID << "\n";
-      return EXIT_SUCCESS;
+      return RET_SUCCESS;
     }
   };
 }
@@ -254,14 +263,15 @@ namespace {
         if (DI == NULL) errs()<<Inst1 << " ";
         if (SI == NULL) errs()<<Inst2 << " ";
         errs() << "\n";
-        return EXIT_FAILURE; }
+        return RET_ERROR; }
 
       if (DI->getType() != SI->getType()) {
         errs()<<"replace failed. could find no use for the result.\n";
-        return EXIT_FAILURE;
+        return RET_ERROR;
       }
 
       temp = SI->clone();
+      temp->setDebugLoc(DebugLoc()); // remove debug information if any 
 
       insertNOP(&*DI);
       ReplaceInstWithInst(DI, temp);
@@ -269,7 +279,7 @@ namespace {
       replaceUnfulfillOperands(temp);
 
       errs()<<"replaced "<< Inst1ID << "," << Inst2ID << "\n";
-      return EXIT_SUCCESS; }
+      return RET_SUCCESS; }
   };
 }
 
@@ -285,7 +295,7 @@ namespace {
         Value* sval = walkExact(Inst2, Inst2ID, M, NULL, false);
         if (sval == NULL){
           errs() << "oprepl failed. cannot find " << Inst2 << "\n";
-          return EXIT_FAILURE;
+          return RET_ERROR;
         }
         std::pair<Instruction*, unsigned> result;
         if (Inst2[0] == 'A')
@@ -302,7 +312,7 @@ namespace {
           );
         if (result.first == NULL) {
           errs() << "oprepl failed. cannot find an OP that has the same type as " << Inst2 << "\n";
-          return EXIT_FAILURE;
+          return RET_ERROR;
         }
 
         Instruction* DI = result.first;
@@ -311,7 +321,7 @@ namespace {
         Inst1ID = getUID(DI).str();
         Inst1ID = Inst1ID + ".OP" + std::to_string(OPidx);
         errs()<<"opreplaced "<< Inst1ID << "," << Inst2ID << "\n";
-        return EXIT_SUCCESS;
+        return RET_SUCCESS;
       }
       else if (Inst1 != "Rand" && Inst2 == "Rand") {
         StringRef dstInstBase = (StringRef(Inst1)).rsplit('.').first;
@@ -321,7 +331,7 @@ namespace {
         Instruction *DI = dyn_cast_or_null<Instruction>(walkExact(dstInstBase.str(), Inst1ID, M, NULL, false));
         if (DI == NULL){
           errs() << "oprepl failed. cannot find" << dstInstBase << "\n";
-          return EXIT_FAILURE;
+          return RET_ERROR;
         }
         Inst1ID = Inst1ID + ".OP" + std::to_string(OPidx);
         Value *Dop = DI->getOperand(OPidx);
@@ -330,7 +340,7 @@ namespace {
         Inst2ID = sval.second.str();
 
         errs()<<"opreplaced "<< Inst1ID << "," << Inst2ID << "\n";
-        return EXIT_SUCCESS;
+        return RET_SUCCESS;
       }
       else if (Inst1 == "Rand" && Inst2 == "Rand") {
         std::pair<Value*, StringRef> val = randValue(M);
@@ -351,7 +361,7 @@ namespace {
           );
         if (result.first == NULL) {
           errs() << "oprepl failed. cannot find an OP that has the same type as " << Inst2ID << "\n";
-          return EXIT_FAILURE;
+          return RET_ERROR;
         }
 
         Instruction* DI = result.first;
@@ -360,12 +370,16 @@ namespace {
         Inst1ID = getUID(DI).str();
         Inst1ID = Inst1ID + ".OP" + std::to_string(OPidx);
         errs()<<"opreplaced "<< Inst1ID << "," << Inst2ID << "\n";
-        return EXIT_SUCCESS;
+        return RET_SUCCESS;
       }
       else { // both != "Rand"
         err = replaceOperands(Inst1, Inst2, M);
         if (err == 0)
-          return EXIT_SUCCESS;
+          return RET_SUCCESS;
+        else if (err == 1) {
+          errs() << "Warning: oprepl ignored. Source and Destination are the same" << "\n";
+          return RET_WARNING;
+        }
         else if (err == -1)
           errs() << "oprepl failed. cannot find" << Inst1 << "\n";
         else if (err == -2)
@@ -374,9 +388,7 @@ namespace {
           errs() << "oprepl failed. source instruction does not have an output" << "\n";
         else if (err == -4)
           errs() << "oprepl failed. type mismatched" << "\n";
-        else if (err == -5)
-          errs() << "oprepl failed. Source and Destination are the same" << "\n";
-        return EXIT_FAILURE;
+        return RET_ERROR;
       }
     }
   };
@@ -397,9 +409,10 @@ namespace {
         if (DI == NULL) errs()<<Inst1 << " ";
         if (SI == NULL) errs()<<Inst2 << " ";
         errs() << "\n";
-        return EXIT_FAILURE; }
+        return RET_ERROR; }
 
       temp = SI->clone();
+      temp->setDebugLoc(DebugLoc()); // remove debug information if any 
       Inst2ID = getUID(SI).str();
 
       temp->insertBefore(&*DI); // insert temp before DI
@@ -422,7 +435,7 @@ namespace {
       SI->eraseFromParent();
 
       errs()<<"moved " << Inst1ID << "," << Inst2ID << "\n";
-      return EXIT_SUCCESS; }
+      return RET_SUCCESS; }
   };
 }
 
@@ -440,10 +453,12 @@ namespace {
         if (I1 == NULL) errs()<<Inst1 << " ";
         if (I2 == NULL) errs()<<Inst2 << " ";
         errs() << "\n";
-        return EXIT_FAILURE; }
+        return RET_ERROR; }
 
       temp1 = I1->clone();
+      temp1->setDebugLoc(DebugLoc());
       temp2 = I2->clone();
+      temp2->setDebugLoc(DebugLoc());
 
       // confirm that the types match
       if(temp1->getType() != temp2->getType()) {
@@ -452,7 +467,7 @@ namespace {
           temp2->getType() << "\n";
         temp1->deleteValue();
         temp2->deleteValue();
-        return EXIT_FAILURE; }
+        return RET_ERROR; }
 
       insertNOP(&*I1);
       insertNOP(&*I2);
@@ -471,7 +486,7 @@ namespace {
 
       errs()<<"swapped " << Inst1ID << "," << Inst2ID << "\n";
 
-      return EXIT_SUCCESS; }
+      return RET_SUCCESS; }
   };
 }
 
@@ -490,7 +505,7 @@ namespace {
         I = dyn_cast_or_null<Instruction>(walkExact(Inst1, Inst1ID, M, NULL, true));
         if (I == NULL) {
           errs() << "cache failed. Cannot find/use " << Inst1 << "\n";
-          return EXIT_FAILURE; }
+          return RET_ERROR; }
       }
 
       Instruction *newI;
@@ -514,12 +529,12 @@ namespace {
       else if (isa<CallInst>(I)){
         if (cast<CallInst>(I)->isIndirectCall()) {
           errs() << Inst1 << " is not a proper instruction for manipulating cache behavior.\n";
-          return EXIT_FAILURE;
+          return RET_ERROR;
         }
         // // Check if called function is ldg()
         // if (!cast<CallInst>(I)->getCalledFunction()->getName().contains(ldgPre)) {
         //   errs() << Inst1 << " is not a proper instruction for manipulating cache behavior.\n";
-        //   return EXIT_FAILURE;
+        //   return RET_ERROR;
         // }
         newI = new LoadInst(
           I->getType(),     // output type
@@ -535,7 +550,7 @@ namespace {
       }
       else{
         errs() << Inst1 << " is not a proper instruction for manipulating cache behavior.\n";
-        return EXIT_FAILURE;
+        return RET_ERROR;
       }
 
       setUID(newI, getUID(I));
@@ -544,7 +559,7 @@ namespace {
       updateMetadata(newI, "x");
 
       errs()<<"cache " << Inst1ID << "\n";
-      return EXIT_SUCCESS;
+      return RET_SUCCESS;
     }
   };
 }
