@@ -17,7 +17,7 @@
 #include "llvm/Support/raw_ostream.h"
 #include "llvm/Transforms/Utils/BasicBlockUtils.h"
 
-#define RET_ERROR -1
+#define RET_ERROR 2
 #define RET_WARNING 1
 #define RET_SUCCESS 0
 
